@@ -126,6 +126,7 @@ FVP_MORELLO_ARGS = [
     [
         [],
         ["--device", "qemu-armv7", "--device-dict", "device.yaml"],
+        ["--device", "qemu-armv7", "--boot-args", 'bla"bl'],
         ["--device", "qemu-armv7", "--dtb", "arm.dtb"],
         ["--device", "qemu-arm64", "--bios", "bios.bin"],
         ["--kernel", "https://storage.tuxboot.com/i386/bzImage"],
@@ -133,15 +134,6 @@ FVP_MORELLO_ARGS = [
         ["--definition", "definition.yaml"],
         ["--device", "fvp-morello-android", "--mcp-fw", "fvp.bin"],
         ["--device", "fvp-morello-android", "--test", "multicore"],
-        [
-            "--device",
-            "fvp-morello-android",
-            *FVP_MORELLO_ARGS,
-            "--tests",
-            "bionic",
-            "--parameters",
-            "USERDATA=userdata.tar.xz",
-        ],
         [
             "--device",
             "fvp-morello-android",
@@ -216,6 +208,20 @@ FVP_MORELLO_ARGS = [
             "--parameters",
             "PDF_URL=http://example.com/pdfium-testfiles.tar.xz",
         ],
+        [
+            "--device",
+            "fvp-morello-android",
+            *FVP_MORELLO_ARGS,
+            "--tests",
+            "ltp-smoke",
+        ],
+        [
+            "--device",
+            "fvp-morello-android",
+            *FVP_MORELLO_ARGS,
+            "--tests",
+            "kselftest",
+        ],
     ],
 )
 def test_command_line_errors(argv, capsys, monkeypatch, mocker, artefacts):
@@ -455,6 +461,7 @@ def test_update_cache(mocker, monkeypatch, capsys):
   * qemu-ppc64le
   * qemu-riscv64
   * qemu-s390
+  * qemu-sh4
   * qemu-sparc64
   * qemu-x86_64
 * Test definitions
