@@ -58,10 +58,10 @@ def run(options, tmpdir: Path) -> int:
     if options.device:
         overlays = []
         if options.modules:
-            overlays.append(("modules", options.modules))
+            overlays.append(("modules", options.modules, "/"))
             extra_assets.append(options.modules)
         for (index, item) in enumerate(options.overlays):
-            overlays.append((f"overlay-{index:02}", item))
+            overlays.append((f"overlay-{index:02}", item, "/"))
             extra_assets.append(item)
 
         # Add test definitions only when needed
@@ -94,7 +94,9 @@ def run(options, tmpdir: Path) -> int:
             tests_timeout=sum(t.timeout for t in options.tests),
             timeouts=options.timeouts,
             tmpdir=tmpdir,
-            tux_boot_args=options.boot_args.replace('"', ""),
+            tux_boot_args=options.boot_args.replace('"', "")
+            if options.boot_args
+            else None,
             parameters=options.parameters,
         )
         LOG.debug("job definition")
