@@ -30,6 +30,7 @@ KERNELS = {
     "qemu-ppc64le": "https://storage.tuxboot.com/ppc64le/vmlinux",
     "qemu-riscv64": "https://storage.tuxboot.com/riscv64/Image",
     "qemu-s390": "https://storage.tuxboot.com/s390/bzImage",
+    "qemu-sh4": "https://storage.tuxboot.com/sh4/zImage",
     "qemu-sparc64": "https://storage.tuxboot.com/sparc64/vmlinux",
     "qemu-x86_64": "https://storage.tuxboot.com/x86_64/bzImage",
 }
@@ -49,12 +50,13 @@ ROOTFS = {
     "qemu-ppc64le": "https://storage.tuxboot.com/ppc64le/rootfs.ext4.zst",
     "qemu-riscv64": "https://storage.tuxboot.com/riscv64/rootfs.ext4.zst",
     "qemu-s390": "https://storage.tuxboot.com/s390/rootfs.ext4.zst",
+    "qemu-sh4": "https://storage.tuxboot.com/sh4/rootfs.ext4.zst",
     "qemu-sparc64": "https://storage.tuxboot.com/sparc64/rootfs.ext4.zst",
     "qemu-x86_64": "https://storage.tuxboot.com/x86_64/rootfs.ext4.zst",
 }
 
 
-TEST_DEFINITIONS = "https://storage.tuxboot.com/test-definitions/2021.04.tar.zst"
+TEST_DEFINITIONS = "https://storage.tuxboot.com/test-definitions/2022.01.tar.zst"
 
 
 def get_rootfs(
