@@ -13,7 +13,15 @@ from tuxrun.exceptions import InvalidArgument
 
 
 class FVPDevice(Device):
-    mandatory = ["mcp_fw", "mcp_romfw", "rootfs", "scp_fw", "scp_romfw", "uefi"]
+    mandatory = [
+        "ap_romfw",
+        "mcp_fw",
+        "mcp_romfw",
+        "rootfs",
+        "scp_fw",
+        "scp_romfw",
+        "fip",
+    ]
 
     prompts: List[str] = []
     auto_login: Dict[str, str] = {}
@@ -23,6 +31,7 @@ class FVPDevice(Device):
 
     def validate(
         self,
+        ap_romfw,
         mcp_fw,
         mcp_romfw,
         rootfs,
@@ -30,20 +39,22 @@ class FVPDevice(Device):
         scp_romfw,
         parameters,
         tests,
-        uefi,
+        fip,
         **kwargs,
     ):
         invalid_args = ["--" + k.replace("_", "-") for k in kwargs if kwargs[k]]
         if len(invalid_args) > 0:
             raise InvalidArgument(
-                f"Invalid option(s) for fvp devices: {', '.join(invalid_args)}"
+                f"Invalid option(s) for fvp devices: {', '.join(sorted(invalid_args))}"
             )
 
         args = locals()
-        missing_args = ["--" + k for k in self.mandatory if not args[k]]
+        missing_args = [
+            "--" + k.replace("_", "-") for k in self.mandatory if not args[k]
+        ]
         if len(missing_args) > 0:
             raise InvalidArgument(
-                f"Missing option(s) for fvp devices: {', '.join(missing_args)}"
+                f"Missing option(s) for fvp devices: {', '.join(sorted(missing_args))}"
             )
 
         if tests and not self.support_tests:
@@ -108,7 +119,7 @@ class FVPMorelloOE(FVPDevice):
 class FVPMorelloUbuntu(FVPDevice):
     name = "fvp-morello-ubuntu"
 
-    mandatory = ["mcp_fw", "mcp_romfw", "scp_fw", "scp_romfw", "uefi"]
+    mandatory = ["ap_romfw", "mcp_fw", "mcp_romfw", "scp_fw", "scp_romfw", "fip"]
 
     prompts = ["morello@morello-server:"]
     auto_login = {
