@@ -26,6 +26,7 @@ class QemuDevice(Device):
     memory: str = ""
 
     extra_options: List[str] = []
+    extra_boot_args: str = ""
 
     console: str = ""
     rootfs_dev: str = ""
@@ -36,6 +37,8 @@ class QemuDevice(Device):
     kernel: str = ""
     rootfs: str = ""
 
+    test_character_delay: int = 0
+
     def validate(
         self,
         bios,
@@ -45,6 +48,7 @@ class QemuDevice(Device):
         kernel,
         modules,
         overlays,
+        parameters,
         partition,
         rootfs,
         tests,
@@ -69,7 +73,7 @@ class QemuDevice(Device):
             raise InvalidArgument("argument --modules should be a .tar.xz")
 
         for test in tests:
-            test.validate(device=self, **kwargs)
+            test.validate(device=self, parameters=parameters, **kwargs)
 
     def definition(self, **kwargs):
         kwargs = kwargs.copy()
@@ -90,6 +94,12 @@ class QemuDevice(Device):
         kwargs["dtb"] = notnone(kwargs.get("dtb"), self.dtb)
         kwargs["kernel"] = notnone(kwargs.get("kernel"), self.kernel)
         kwargs["rootfs"] = notnone(kwargs.get("rootfs"), self.rootfs)
+        if self.extra_boot_args:
+            if kwargs["tux_boot_args"]:
+                kwargs["tux_boot_args"] = kwargs.get("tux_boot_args") + " "
+            else:
+                kwargs["tux_boot_args"] = ""
+            kwargs["tux_boot_args"] += self.extra_boot_args
 
         # Computed values
         kernel = kwargs.get("kernel")
@@ -100,11 +110,19 @@ class QemuDevice(Device):
             kernel_compression = "xz"
         kwargs["kernel_compression"] = kernel_compression
 
+        rootfs_compression = "zstd"
+        if kwargs["rootfs"].endswith(".gz"):
+            rootfs_compression = "gz"
+        kwargs["rootfs_compression"] = rootfs_compression
+
         # render the template
         tests = [
             t.render(
                 arch=kwargs["arch"],
                 command=kwargs["command"],
+                device=kwargs["device"],
+                overlays=kwargs["overlays"],
+                parameters=kwargs["parameters"],
                 test_definitions=kwargs["test_definitions"],
             )
             for t in kwargs["tests"]
@@ -116,6 +134,8 @@ class QemuDevice(Device):
         )
 
     def device_dict(self, context):
+        if self.test_character_delay:
+            context["test_character_delay"] = self.test_character_delay
         return templates.devices().get_template("qemu.yaml.jinja2").render(**context)
 
 
@@ -347,6 +367,26 @@ class QemuS390(QemuDevice):
     rootfs = "https://storage.tuxboot.com/s390/rootfs.ext4.zst"
 
 
+class QemuSh4(QemuDevice):
+    name = "qemu-sh4"
+
+    arch = "sh4"
+    lava_arch = "sh4"
+    machine = "r2d"
+    cpu = "sh7785"
+
+    extra_boot_args = "noiotrap"
+
+    console = "ttySC1"
+    rootfs_dev = "/dev/sda"
+    rootfs_arg = "-drive file={rootfs},if=ide,format=raw -serial null -serial stdio"
+
+    kernel = "https://storage.tuxboot.com/sh4/zImage"
+    rootfs = "https://storage.tuxboot.com/sh4/rootfs.ext4.zst"
+
+    test_character_delay = 5
+
+
 class QemuSPARC64(QemuDevice):
     name = "qemu-sparc64"
 
