@@ -42,6 +42,15 @@ def dispatchers():
     )
 
 
+@cache
+def tests():
+    return jinja2.Environment(
+        autoescape=False,
+        trim_blocks=True,
+        loader=jinja2.FileSystemLoader(str(BASE / "tests")),
+    )
+
+
 @cache
 def wrappers():
     return jinja2.Environment(
@@ -49,31 +58,3 @@ def wrappers():
         trim_blocks=True,
         loader=jinja2.FileSystemLoader(str(BASE / "wrappers")),
     )
-
-
-def tests_list():
-    names = []
-    for name in jobs().list_templates(extensions=["jinja2"]):
-        if not name.endswith(".yaml.jinja2"):
-            continue  # pragma: no cover
-        name = name[: -1 * len(".yaml.jinja2")]
-
-        if not name.startswith("tests/"):
-            continue
-        name = name[len("tests/") :]  # noqa: E203
-
-        if name.startswith("base-"):
-            continue
-        names.append(name)
-    return sorted(names)
-
-
-def timeouts():
-    ret = {}
-    for test in tests_list():
-        tmpl = jobs().get_template(f"tests/{test}.yaml.jinja2")
-        ast = jobs().parse(Path(tmpl.filename).read_text(encoding="utf-8"))
-        for node in ast.find_all(jinja2.nodes.Assign):
-            if node.target.name == "timeout":
-                ret[test] = node.node.value
-    return ret
